yakumo.neutron.v2.vpn.ipsec_site_connection.Resource

Package yakumo :: Package neutron :: Package v2 :: Package vpn :: Module ipsec_site_connection :: Class Resource |
[hide private]
[frames] | no frames]

# Class Resource

source code

       object --+
                |
    base.Resource --+
                    |
                   Resource

Resource class for VPN IPSec site connections in Networking V2 API

Instance Methods | [hide private]
None |
update(self, name=`'``__UNDEF__``'`, description=`'``__UNDEF__``'`, peer_address=`'``__UNDEF__``'`, peer_id=`'``__UNDEF__``'`, local_ep_group_id=`'``__UNDEF__``'`, peer_ep_group_id=`'``__UNDEF__``'`, peer_cidrs=`'``__UNDEF__``'`, mtu=`'``__UNDEF__``'`, psk=`'``__UNDEF__``'`, initiator=`'``__UNDEF__``'`, dpd=`'``__UNDEF__``'`, action=`'``__UNDEF__``'`, interval=`'``__UNDEF__``'`, timeout=`'``__UNDEF__``'`, is_enabled=`'``__UNDEF__``'`) Update properties of an IPSec site connection | source code
Inherited from `base.Resource`: `__eq__`, `__getattr__`, `__init__`, `__ne__`, `__repr__`, `__str__`, `delete`, `get_attrs`, `get_id`, `reload`, `wait_for_finished` Inherited from `base.Resource` (private): `_clear_attrs`, `_set_attrs` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Variables | [hide private]
Inherited from `base.Resource` (private): `_attrs`, `_id`, `_loaded`, `_stable_state`, `_state_attr`, `_sub_manager_list`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### update(self, name=`'``__UNDEF__``'`, description=`'``__UNDEF__``'`, peer_address=`'``__UNDEF__``'`, peer_id=`'``__UNDEF__``'`, local_ep_group_id=`'``__UNDEF__``'`, peer_ep_group_id=`'``__UNDEF__``'`, peer_cidrs=`'``__UNDEF__``'`, mtu=`'``__UNDEF__``'`, psk=`'``__UNDEF__``'`, initiator=`'``__UNDEF__``'`, dpd=`'``__UNDEF__``'`, action=`'``__UNDEF__``'`, interval=`'``__UNDEF__``'`, timeout=`'``__UNDEF__``'`, is_enabled=`'``__UNDEF__``'`) | source code
Update properties of an IPSec site connection Parameters: `name` (str) - IPSec site connection name `description` (str) - Description `peer_address` (str) - Peer address `peer_id` (str) - Peer ID `local_ep_group_id` (str) - Local EP group ID `peer_ep_group_id` (str) - Peer EP group ID `peer_cidrs` (str) - Peer CIDRs `mtu` (int) - MTU `psk` (str) - PSK `initiator` (str) - Initiator `dpd` (str) - DPD `action` (str) - Action `interval` (str) - Interval `timeout` (int) - Timeout `is_enabled` (bool) - Whether the connection is enabled Returns: None Overrides: base.Resource.update